/**
 * The wix-dashboard module contains functionality for interacting with your site's dashboard in the code for dashboard pages.
 * 	[Read more](https://www.wix.com/corvid/reference/wix-dashboard.html#)
 */
declare module 'wix-dashboard' {
    /**
     * Navigates the user to another page in the dashboard.
     * 	[Read more](https://www.wix.com/corvid/reference/wix-dashboard.html#navigate)
     */
    function navigate(pageId: string): void;
    /**
     * Displays a toast notification at the top of a dashboard page.
     *
     * ![Toast notification](/images/toast_example.png "Toast notification")
     * 	[Read more](https://www.wix.com/corvid/reference/wix-dashboard.html#showToast)
     */
    function showToast(config: ToastConfig): ToastReturn;
    /**
     * ToastAction Object
     */
    type ToastAction = {
        /**
         * Text that appears in the call-to-action.
         */
        text: string;
        /**
         * The type of call-to-action.
         *
         * Options: `"button"`, `"link"`
         *
         * Default: `"button"`
         */
        uiType?: string;
        /**
         * Whether to remove the toast after the call-to-action is clicked.
         *
         * Default: `true`
         */
        removeToastOnClick?: boolean;
        /**
         * Callback function to run after the call-to-action is clicked.
         */
        onClick: Function;
    };
    /**
     * ToastConfig Object
     */
    type ToastConfig = {
        /**
         * Text that appears in the toast.
         */
        message: string;
        /**
         * Whether the toast removes itself or not.
         *
         * Options:
         * - `"normal"`: The toast removes itself after 6 seconds.
         * - `"none"`: The toast doesn't remove itself.
         *
         * Default: `"normal"`
         */
        timeout?: string;
        /**
         * Toast color and message type.
         *
         * Options:
         * - `"standard"`: Blue toast.
         * - `"success"`: Green toast.
         * - `"warning"`: Yellow warning toast.
         * - `"error"`: Red error toast.
         *
         * Default: `"standard"`
         */
        type?: string;
        /**
         * Priority of the toast. If several toasts are triggered at the same time, they're displayed in the order of their priority levels.
         *
         * Options: `"low"`, `"normal"`, `"high"`
         *
         * Default: `"normal"`
         */
        priority?: string;
        /**
         * Object representing a call-to-action that's displayed in the toast.
         */
        action?: ToastAction;
        /**
         * Callback function to run when the toast is closed by clicking its close button.
         */
        onCloseClick?: Function;
        /**
         * Callback function to run when the toast is seen by the user.
         */
        onToastSeen?: Function;
    };
    /**
     * ShowToast Return Object
     */
    type ToastReturn = {
        /**
         * Removes the displayed toast.
         */
        remove: Function;
    };
}
